@@ -30,6 +30,11 @@ class PyblobLogger:
         self.debug_logger.setLevel(self.DEBUG_LEVEL)
 
         logging.getLogger("azure.core.pipeline.policies.http_logging_policy").setLevel(logging.WARNING)
+        logging.getLogger("uamqp.authentication.cbs_auth").setLevel(logging.WARNING)
+        logging.getLogger("uamqp.connection").setLevel(logging.WARNING)
+        logging.getLogger("uamqp.receiver").setLevel(logging.WARNING)
+        logging.getLogger("uamqp.*").setLevel(logging.WARNING)
+        logging.getLogger("uamqp").setLevel(logging.WARNING)
 	 
         file_handler = logging.FileHandler(self.get_debug_logs_name())
         file_handler.setLevel(self.DEBUG_LEVEL)
@@ -49,6 +54,11 @@ class PyblobLogger:
         self.error_logger.setLevel(self.ERROR_LEVEL)
 
         logging.getLogger("azure.core.pipeline.policies.http_logging_policy").setLevel(logging.WARNING)
+	logging.getLogger("uamqp.authentication.cbs_auth").setLevel(logging.WARNING)
+        logging.getLogger("uamqp.connection").setLevel(logging.WARNING)
+        logging.getLogger("uamqp.receiver").setLevel(logging.WARNING)
+        logging.getLogger("uamqp.*").setLevel(logging.WARNING)
+        logging.getLogger("uamqp").setLevel(logging.WARNING)
 
         file_handler = logging.FileHandler(self.get_error_logs_name())
         file_handler.setLevel(self.ERROR_LEVEL)
